@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20131031';
+our $VERSION = '0.20131129';
 
-# Table last modified: 2013-10-31
+# Table last modified: 2013-11-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -18,7 +18,7 @@ our %ZIP_TABLE = (
     '011' => '(?:8(?:5(?:[58]5|01|20|77|1[01])|6(?:05|11|86)))',
     '012' => '(?:8(?:5(?:11|0[12])|6(?:51|0[14])))',
     '013' => '(?:(?:8(?:5(?:92|0[1-4])|60[129])|0498))',
-    '014' => '(?:(?:0(?:39[2-4]|[25]92)|1(?:192|298)|86[01]1))',
+    '014' => '(?:(?:0(?:39[2-4]|[25]92)|8(?:50|6[01])1|1(?:192|298)))',
     '015' => '(?:(?:8(?:5(?:30|43|67|85|1[015]|5[58]|0[15])|6(?:[24]2|11|30|66|0[12]|8[68]))|0295))',
     '016' => '(?:8(?:5(?:01|55)|60[12]))',
     '017' => '(?:(?:8(?:5(?:10|67|85|5[05])|686)|029[23]))',
@@ -106,9 +106,9 @@ our %ZIP_TABLE = (
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[1589])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|30|77|8[0-35]|2[45]|1[125689])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|8[2457]|7[02358]|4[0-3578]|3[0-8]|2[124589]|5[0-2589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|6[067]|3[13-8]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
+    '103' => '(?:8(?:2(?:0[1-6]|5[0-259]|1[0-2478]|6[0135]|8[2457]|7[02358]|4[0-3578]|3[0-8]|2[124589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[02-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|8[4-689]|2[0-25]|5[24-68]|6[067]|3[13-8]|4[238]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-8])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|5(?:1[028]|3[0135689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:7[027-9]|4[04]|1[0-3579]|8[01368]|2[014589]|5[167]|6[05]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-3]|3[2-7]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|1[0-24-69])|5(?:4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:0[127]|1[1267]))|7444))',
+    '105' => '(?:(?:8(?:4(?:7[0-3]|3[2-7]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|1[0-24-69])|5(?:4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|6[0-35-79]|7[136-8]|1[458]|4[13-5]|2[12]|3[1257]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|3[069])|0(?:[01]1|39)|401|797)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[079]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[1358]|1[0-25]|4[03-578]|6[048]|3[0236]|0[12579]|5[0-36-9]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|8[0134689]|1[35]|6[01]|4[15]|7[02389]|0[3578])|2(?:7[056]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2]|1[017])|4(?:[56]6|85|0[347]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|1[0-25-7]|2[28]|4[0-268])|0(?:[17]1|[25]0|8[08]|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
@@ -131,7 +131,7 @@ our %ZIP_TABLE = (
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
     '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:[25]0|8[3-578]|7[025]|0[13]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-35])|2(?:10|22)|080))',
-    '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
+    '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|7[0157]|2[0267]|4[08]|1[125]|0[3578])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|4[0137-9]|8[03]|3[0136-9]|7[1-36]|6[0367]|2[013569]|0[25-8]|5[0-28]|1[1256])|6(?:01|7[02578]|4[04]|6[0168]|1[13-79]|2[13568]|3[01479]|8[0278]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
     '141' => '(?:8(?:6(?:2[01379]|3[0137-9]|4[02-46-8]|0[2-6]|8[048]|6[03-5]|7[1-39]|1[01356]|5[06-8])|5(?:34|4[04]|0[13-578]|5[59]|2[0-25]|1[02579]|6[0-25-8]|8[0248]|7[267])|4(?:2[0-3]|1[1-9])|7(?:0[17]|1[05])|001))',
@@ -229,7 +229,7 @@ our %ZIP_TABLE = (
     '247' => '(?:8(?:5(?:[135]0|88|7[07])|6(?:30|86)|730))',
     '248' => '(?:8(?:55[58]|686))',
     '249' => '(?:8(?:510|686))',
-    '250' => '(?:(?:0(?:2(?:80|9[2-68])|39[28]|[15]92)|85(?:11|55|88)))',
+    '250' => '(?:(?:0(?:2(?:80|9[2-68])|39[28]|[15]92|493)|85(?:11|55|88)))',
     '251' => '(?:8(?:5(?:22|40|5[0158]|3[0134]|1[0135]|6[067]|8[18]|0[125])|601))',
     '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|1[01]|2[125]|5[0258]|9[2-578])|1(?:[56]2|8[13589]|7[27]|9[1256]))|0(?:3(?:7[03-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:01|10|22|43|67|7[17]|8[58]|5[05]|3[01])|686)|019[256]))',
@@ -263,7 +263,7 @@ our %ZIP_TABLE = (
     '286' => '(?:(?:85(?:[02]1|8[58])|029[23]))',
     '287' => '(?:(?:8(?:5(?:[58]5|10|0[1-3])|601)|0292))',
     '288' => '(?:8601)',
-    '289' => '(?:(?:1(?:59[2-4]|[138]92|29[78]|69[23]|79[23])|0(?:[124-6]92|39[2-4])|2(?:19[278]|292|595)))',
+    '289' => '(?:(?:1(?:59[2-4]|[138]92|29[78]|69[23]|79[23])|0(?:[124-6]92|39[23])|2(?:19[278]|292|595)))',
     '290' => '(?:(?:8(?:5(?:77|6[06]|0[13]|5[0158]|8[58]|[13][01])|610)|019[2-4]))',
     '292' => '(?:8(?:5(?:01|2[025]|3[0359]|6[58]|5[05]|1[01])|6(?:11|86)))',
     '293' => '(?:85(?:06|11))',
@@ -275,7 +275,7 @@ our %ZIP_TABLE = (
     '299' => '(?:(?:4(?:39[24-6]|[126]92|49[23])|0(?:29[235-8]|19[2-58])|2(?:[1245]92|79[25])|5(?:29[25]|192)|119[245]))',
     '300' => '(?:(?:2(?:6(?:86|9[58])|49[2-578]|79[23578]|395|593)|0(?:39[2-8]|19[23]|49[26]|59[35]|[67]92)|1(?:29[24-6]|19[235]|[34]92|696)|8(?:5(?:50|67|88)|6(?:01|19|86))|4(?:19[23]|29[35]|495|598)|3(?:59[258]|29[45])))',
     '301' => '(?:8(?:6(?:0[12]|1[01])|5(?:55|0[15])))',
-    '302' => '(?:(?:85(?:0[12]|8[56])|019[28]))',
+    '302' => '(?:(?:85(?:0[12]|8[56])|0198))',
     '303' => '(?:850[13])',
     '304' => '(?:8[56]01)',
     '305' => '(?:8(?:5(?:[58]5|6[1-9]|2[01]|1[56]|0[1346])|6(?:42|0[1249]|8[67])))',
@@ -310,7 +310,7 @@ our %ZIP_TABLE = (
     '334' => '(?:8501)',
     '335' => '(?:8(?:5(?:10|22|33|55|8[58]|0[125])|6(?:55|66)|792))',
     '336' => '(?:8(?:5(?:40|6[14]|1[25]|2[1-356]|8[67]|[05][58])|6(?:01|36|55)|760))',
-    '337' => '(?:85(?:32|70|86|0[27]))',
+    '337' => '(?:85(?:32|70|86|0[127]))',
     '338' => '(?:8(?:5(?:8[056]|2[3-5]|0[3-68]|6[67]|7[0157]|1[0235]|3[18]|4[01]|5[13578])|6(?:30|86)))',
     '339' => '(?:8(?:5(?:[02]1|39|66|85|5[18]|1[01])|6(?:01|86)))',
     '340' => '(?:(?:8(?:5(?:24|33|77|5[015]|0[19]|8[58]|6[078]|1[01])|6(?:59|86|1[01]))|0(?:19[23]|295)))',
@@ -344,16 +344,16 @@ our %ZIP_TABLE = (
     '368' => '(?:(?:8(?:6(?:66|8[06])|50[125])|0(?:19[235]|292)))',
     '369' => '(?:(?:1(?:29[2358]|89[2-5]|19[235]|59[236]|[34]92|998)|0(?:29[2357]|19[258]|39[235])))',
     '370' => '(?:(?:8(?:5(?:[01]1|[68]5|22|43|3[17]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[23]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
-    '371' => '(?:(?:8(?:5(?:39|43|67|70|85|0[1-578]|2[258]|1[0-467]|5[01])|6(?:[01]1|[68]6|40))|0(?:192|294)))',
+    '371' => '(?:(?:8(?:5(?:2[02578]|0[1-578]|1[0-7]|8[0568]|4[38]|3[01359]|5[015-7]|7[023]|6[017])|6(?:[36]6|01|40|77|1[167]|2[05]|8[68]))|0(?:29[2-4]|192)))',
     '372' => '(?:8(?:5(?:58|67|8[058]|0[128])|686))',
-    '373' => '(?:8(?:5(?:21|40|78|0[1589]|1[0135]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|39|6[06]|8[68]|1[01])|718))',
+    '373' => '(?:8(?:5(?:21|78|0[1589]|1[0135]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|6[06]|8[68]|1[01])|718))',
     '374' => '(?:(?:8(?:5(?:01|20|33|55|77|88|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
     '375' => '(?:8(?:50[1-6]|60[1-4]))',
     '376' => '(?:(?:8(?:5(?:31|85|0[1-3]|1[056]|2[38]|5[58])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
     '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|19[235]|29[2-4]|39[25]|49[24]|792)|8(?:5(?:[67]7|20|33|55|1[013]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
     '378' => '(?:(?:0498|8501))',
     '379' => '(?:(?:2(?:1(?:8[01457]|9[2-578])|39[258]|29[28])|1(?:[16]92|[24]98|393)|0(?:19[2356]|292)))',
-    '380' => '(?:8(?:5(?:8[013-689]|5[0-2578]|0[1-8]|7[0235-7]|6[015-8]|2[0-24-6]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|0[158]|2[25]|3[0359]|8[268]|6[068]|4[08]|1[0-24])|79[4-8]))',
+    '380' => '(?:8(?:5(?:8[013-689]|5[0-2578]|7[0-35-7]|0[1-8]|6[015-8]|2[0-24-6]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|0[158]|2[25]|3[0359]|8[268]|6[068]|4[08]|1[0-24])|79[4-8]))',
     '381' => '(?:(?:8(?:5(?:1[015]|[67][07]|3[09]|0[138]|4[58]|2[05]|8[08]|5[68])|6(?:02|86)|793)|0(?:29[23578]|19[23]|49[78])|22(?:8[0-35-8]|9[258])|4(?:19[23]|393)))',
     '382' => '(?:8(?:5(?:33|55|0[128]|8[578]|1[0-2])|633))',
     '383' => '(?:8(?:5(?:55|67|8[158]|[01][15])|6(?:14|86)))',
@@ -363,7 +363,7 @@ our %ZIP_TABLE = (
     '387' => '(?:8(?:5(?:[26]1|[58]5|0[1-3]|1[12])|60[13]))',
     '388' => '(?:85(?:11|22|55))',
     '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[24-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2(?:[1357]92|29[28])))',
-    '390' => '(?:(?:8(?:5(?:55|0[1-35-8]|4[013]|1[0158]|3[01359]|2[035])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:0[237]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
+    '390' => '(?:(?:8(?:5(?:0[1-35-8]|4[013]|1[0158]|3[01359]|5[05]|2[035])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:0[237]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
     '391' => '(?:(?:85(?:31|40|0[13]|5[058]|6[07]|1[0-2]|8[08]|2[15])|0(?:29[2-6]|39[2-6]|192)))',
     '392' => '(?:8(?:5(?:[58]5|20|7[78]|0[25]|4[089]|1[01])|6(?:86|2[78]|0[19]|1[01])))',
     '393' => '(?:8(?:5(?:11|85|0[1-3])|601))',
@@ -480,7 +480,7 @@ our %ZIP_TABLE = (
     '508' => '(?:(?:8(?:5(?:[58]5|11|0[0-2])|6(?:[68]6|11))|0(?:292|494)))',
     '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|19[23]|69[25]|492)|0(?:29[24578]|19[278]|393|492)|2(?:59[2358]|29[235])|5(?:19[2358]|292|494)|9(?:29[23568]|19[25])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
     '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[3-5]|8[058]|1[0-25]|7[57]|2[0258]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
-    '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-6]|19[28]|59[23]|492)|1192))',
+    '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-68]|19[28]|59[23]|492)|1192))',
     '512' => '(?:85(?:12|38|50))',
     '513' => '(?:8(?:6(?:[57]0|01|8[06]|3[0-3]|6[016])|5(?:[1-3]0|0[15])|701))',
     '514' => '(?:(?:8(?:5(?:4[0356]|3[0-38]|1[0-58]|8[568]|7[01578]|2[0-2468]|5[02358]|0[1-3578]|6[06-8])|6(?:[01]1|[68]6|3[35]))|2(?:39[23568]|29[2-4]|192)|1(?:29[2-7]|19[235])|039[235-7]))',
@@ -491,7 +491,7 @@ our %ZIP_TABLE = (
     '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
     '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|7[057]|5[058]|1[1-356])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
     '521' => '(?:(?:1(?:29[25]|39[28]|192)|8(?:60|5[0-2])1|0[23]92))',
-    '522' => '(?:(?:8(?:5(?:11|40|3[39]|0[13]|8[58]|2[023])|6(?:55|66))|029[27]))',
+    '522' => '(?:(?:8(?:5(?:11|40|0[135]|3[39]|8[58]|2[023])|6(?:55|66))|029[27]))',
     '523' => '(?:8(?:5(?:23|0[1-3]|5[58]|1[05])|651))',
     '524' => '(?:(?:85(?:01|24|77|85)|0292))',
     '525' => '(?:85(?:77|2[0-25]|6[67]|[58][58]|1[15]|0[125]))',
@@ -501,7 +501,7 @@ our %ZIP_TABLE = (
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
     '530' => '(?:8(?:2(?:8[0-278]|3[0249]|5[0-256]|6[0236]|4[0157]|2[126-8]|1[0-8]|7[08]|0[1-79])|5(?:44|2[1-3]|6[05-7]|5[0-2568]|0[14]|7[4578]|3[15]|1[1-37]|8[023568])|3(?:3[348]|0[148]|1[018]|8[389]|4[16]|2[1-47]|5[035])|4(?:75|80|1[015]|0[1-38]|4[18])|6(?:1[018]|0[12]|8[08])|79[136-8]))',
     '531' => '(?:(?:8(?:5(?:26|67|88|0[1-3]|5[58]|1[01])|787)|6053))',
-    '532' => '(?:8(?:5(?:35|60|2[045]|5[058]|8[58]|0[1578]|1[145])|680))',
+    '532' => '(?:8(?:5(?:35|60|2[045]|[58][58]|0[1578]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
     '534' => '(?:85(?:11|85|0[12]))',
     '535' => '(?:85(?:[58]5|01))',
@@ -510,7 +510,7 @@ our %ZIP_TABLE = (
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
     '540' => '(?:(?:8(?:5(?:66|4[0147]|2[1267]|5[01589]|3[03-5]|8[15-8]|0[1578]|7[01578]|1[0-2579])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
-    '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|7[1568]|4[0-35-7]|8[1579]|0[1-35689]|1[16-8]|6[368]|3[014578])|6666))',
+    '541' => '(?:(?:85(?:5[0136-9]|2[013-689]|4[0-35-7]|7[12568]|8[1579]|0[1-35689]|1[16-8]|6[368]|3[014578])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|[58][58]|0[12])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:01|55)|666))',
@@ -540,7 +540,7 @@ our %ZIP_TABLE = (
     '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:[68]6|34|77)))',
     '571' => '(?:8(?:5(?:[45]5|67|71|8[05]|0[2-47])|6(?:33|86)))',
     '572' => '(?:85(?:40|67|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|1[01]))',
-    '573' => '(?:(?:8(?:5(?:11|34|73)|666)|10(?:[134]0|01)|019[25]))',
+    '573' => '(?:(?:8(?:5(?:34|56|73|1[01])|666)|10(?:[134]0|01)|019[25]))',
     '574' => '(?:85(?:[58]5|01|3[04]))',
     '575' => '(?:85(?:[01]1|30|[58][58]))',
     '576' => '(?:8501)',
@@ -563,7 +563,7 @@ our %ZIP_TABLE = (
     '595' => '(?:8(?:5(?:85|5[58])|6(?:50|86)))',
     '596' => '(?:8(?:6(?:[25]4|86)|5(?:10|88)))',
     '597' => '(?:8(?:5(?:22|43|55|8[58]|0[12]|1[15])|686))',
-    '598' => '(?:85(?:[13]1|22|6[06]|0[389]|5[05]))',
+    '598' => '(?:85(?:[13]1|22|40|6[06]|0[389]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
     '600' => '(?:8(?:5(?:4[04]|3[03]|1[19]|5[058]|8[1568]|7[07]|6[067]|2[56]|0[1-35])|6(?:52|65|8[68])|7(?:11|87)))',
     '601' => '(?:(?:85(?:[25]0|01|42|88|3[03]|1[01])|0(?:292|797)|1(?:192|495)))',
@@ -631,7 +631,7 @@ our %ZIP_TABLE = (
     '667' => '(?:(?:8(?:555|651)|0198))',
     '668' => '(?:(?:8(?:6(?:66|5[05])|501)|0(?:29[238]|393)))',
     '669' => '(?:(?:3(?:39[24-6]|19[28]|69[23]|892)|5(?:19[2378]|39[258]|292)|6(?:[2578]92|19[25])|2(?:[12]92|397)|159[25]|4[13]92))',
-    '670' => '(?:8(?:5(?:43|3[03]|7[057]|8[058]|6[67]|5[0458]|2[024]|1[017]|0[1256])|6(?:7[057]|5[25]|6[068]|8[029])))',
+    '670' => '(?:8(?:5(?:43|3[03]|7[057]|8[058]|0[1-356]|6[67]|5[0458]|2[024]|1[017])|6(?:7[057]|5[25]|6[068]|8[029])))',
     '671' => '(?:(?:1(?:2(?:9[235]|8[0-35689])|6(?:92|8[0-248])|1(?:92|8[018])|59[235]|39[23])|2(?:19[238]|59[358]|28[08])|419[23]|0295))',
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
     '673' => '(?:(?:8(?:5(?:11|85)|6[68]6)|1(?:49[3-5]|192|395)|0[45]92))',
@@ -689,7 +689,7 @@ our %ZIP_TABLE = (
     '729' => '(?:(?:3(?:49[278]|19[23]|592)|0(?:49[25]|292|393)|2(?:39[2-4]|292)|149[23]|4295|5792))',
     '730' => '(?:8(?:5(?:8[0235-9]|6[1-35-7]|4[0-358]|1[013-58]|5[0-289]|0[1-47-9]|7[015-7]|3[0-35689]|2[0-378])|6(?:7[02578]|4[1-36]|1[0-29]|8[067]|0[1-35689]|6[126-8]|5[0-8]|3[01]|2[026])|7(?:12|87|2[02]|3[09]|0[167]|9[4-8])))',
     '731' => '(?:(?:0(?:19[2-7]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[2368]|29[2-4])|1(?:59[57]|795)|519[3578]|219[58]))',
-    '732' => '(?:8(?:5(?:6[4-68]|1[0-2]|0[13-57-9])|7(?:65|91)|652))',
+    '732' => '(?:8(?:5(?:55|70|6[4-68]|1[0-2]|0[13-57-9])|7(?:65|91)|652))',
     '733' => '(?:8(?:6(?:3[03]|2[1-6]|4[1-36-8]|7[0578]|0[18]|5[01]|6[069]|1[016])|5(?:01|4[0358]|5[0-358]|2[0158]|3[0135]|1[0-4])|701))',
     '734' => '(?:8(?:5(?:[37]0|22|43|58|6[07]|1[035])|798))',
     '735' => '(?:8(?:5(?:01|10|55|77|88)|6(?:70|86)))',
@@ -726,9 +726,9 @@ our %ZIP_TABLE = (
     '767' => '(?:85(?:07|85|1[0-3]))',
     '768' => '(?:(?:8(?:50[12]|60[12])|019[25]))',
     '769' => '(?:(?:2(?:7(?:88|9[24-6])|69[2356]|19[235]|[349]92)|1(?:6(?:89|9[4-68])|192|593)|0(?:19[2-578]|29[2356])))',
-    '770' => '(?:8(?:5(?:7[0-3]|5[0-258]|0[1-9]|1[0-68]|3[0-35-9]|2[0-689]|4[0146-8]|8[58]|6[0357])|6(?:10|48|0[15])|7(?:87|9[48])))',
+    '770' => '(?:8(?:5(?:7[0-3]|1[0-24-68]|5[0-258]|0[1-9]|3[0-35-9]|2[0-689]|4[0146-8]|8[58]|6[0357])|6(?:10|48|0[15])|7(?:87|9[48])))',
     '771' => '(?:(?:0(?:1(?:8[235-9]|9[2-68])|2(?:8[57-9]|9[2-68]))|1(?:2(?:89|9[24578])|49[2-48]|[357]92|19[23]|695)|(?:33|2[135]|4[13]|5[24])95|6(?:192|495)))',
-    '772' => '(?:8(?:5(?:20|1[015]|0[1-35])|601))',
+    '772' => '(?:8(?:5(?:20|1[015]|0[1-3])|601))',
     '773' => '(?:8(?:50[124]|601))',
     '774' => '(?:8[56]01)',
     '775' => '(?:(?:0[235]95|8570))',
@@ -737,7 +737,7 @@ our %ZIP_TABLE = (
     '778' => '(?:(?:850[13-7]|0[12]95))',
     '779' => '(?:(?:3(?:39[3-5]|[4-6]95|29[58])|1(?:29[235]|19[58])|4(?:[478]95|19[35])|(?:53|2[13])95|019[2-5]))',
     '780' => '(?:8(?:5(?:4[01458]|0[1-9]|2[0-35-9]|3[02-9]|6[0-25-8]|5[03-689]|1[0-8]|7[0-27])|6(?:7[05-7]|6[0-2568]|8\d|0[125])|787))',
-    '781' => '(?:(?:5(?:19[25]|29[25]|79[23]|495)|85(?:21|43|60|1[015]|5[1257])|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
+    '781' => '(?:(?:85(?:21|43|60|88|1[015]|5[1257])|5(?:19[25]|29[25]|79[23]|495)|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
     '782' => '(?:8502)',
     '783' => '(?:85(?:55|0[125-9]))',
     '784' => '(?:850[135])',
@@ -750,7 +750,7 @@ our %ZIP_TABLE = (
     '791' => '(?:(?:8(?:5(?:51|2[3-578]|1[0-36-8]|3[01568]|0[125-8])|6(?:0[34]|7[1257]))|0(?:2(?:8[018]|9[257])|3(?:85|9[23578])|59[34])|3(?:19[2-8]|29[235]|[35]92)|(?:45|1[17])92|219[135]))',
     '792' => '(?:8(?:5(?:43|67|1[018]|8[0568]|5[05]|2[01]|0[15])|6(?:14|70|86)))',
     '793' => '(?:8(?:5(?:[58]5|0[19]|1[05])|601))',
-    '794' => '(?:(?:8(?:5(?:82|1[018]|0[28])|6(?:0[1278]|1[14]))|2(?:39[25]|59[23]|[12]92)|1(?:39[23]|[14]92)|019[23]))',
+    '794' => '(?:(?:8(?:5(?:82|1[018]|0[28])|6(?:1[14]|0[12]))|2(?:39[25]|59[23]|[12]92)|1(?:39[23]|[14]92)|019[23]))',
     '795' => '(?:(?:8(?:5(?:0[124-8]|1[01])|60[1-3])|0392))',
     '796' => '(?:(?:0(?:29[235]|495|892)|850[12]))',
     '797' => '(?:(?:(?:02|1[257])92|85[01]1))',
@@ -874,7 +874,7 @@ our %ZIP_TABLE = (
     '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|39[38]|198)))',
     '918' => '(?:8(?:5(?:4[03]|5[0568]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|0[1-358]|8[03568])|68[168]))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
-    '920' => '(?:(?:8(?:5(?:0[1-9]|4[0134]|2[0-25]|3[0135-9]|7[0357]|1[0-3578]|5[0-8]|6[0135-8]|8[035-8])|6(?:2[0-356]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|8[01568]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|0[137]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
+    '920' => '(?:(?:8(?:5(?:0[1-9]|4[0134]|2[0-25]|3[0135-9]|7[0357]|1[0-3578]|5[0-8]|6[0135-8]|8[035-8])|6(?:2[0-356]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|8[01568]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|0[17]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|8[0-489]|0[15-8]|2[035-79]|4[1468]|7[1-79])|6(?:01|50|3[079]|1[126]|2[01])|798))',
     '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[2-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:5[0-257]|8[0168]|3[013]|2[0158]|0[1-357]|6[067]|7[078]|4[14-6]|1[01])|6(?:50|66|2[06]|4[2-46]|1[0156]|8[68]|0[135689]|3[039]))|1(?:29[2-7]|198)|039[238]))',
@@ -905,7 +905,7 @@ our %ZIP_TABLE = (
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|59[24]|277|392)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|2(?:19[2-4]|39[24])|4(?:19[2-4]|392)|5(?:49[2-4]|292)|039[23]|8492))',
     '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|0[1-57]|5[0-35-9]|7[0-25-79]|4[013-8]|1[0-248]|3[0-579]|8[0-35689])|6(?:7[78]|6[0168]|5[0145]|0[1-3568]|1[0-39]|4[01]|2[0-69]|8[016]|3[039])|7(?:2[0-47]|0[7-9]|5[01359]|3[0235-8]|1[01578]|9[48]|4[0-24-9])|801)|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-35-8])|29[2-8]|49[258])|0(?:19[23568]|292)|3(?:19[58]|393)))',
-    '951' => '(?:8(?:5(?:3[0136]|4[045]|7[07]|5[0-256]|6[067]|8[01568]|0[1-48]|1[0-24589]|2[0-28])|6(?:01|3[23]|8[056]|5[05]|2[029]|1[0-2]|[67][68])))',
+    '951' => '(?:8(?:5(?:3[0136]|4[045]|7[07]|5[0-256]|6[067]|1[0-589]|8[01568]|0[1-48]|2[0-28])|6(?:01|3[23]|8[056]|5[05]|2[029]|1[0-2]|[67][68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|501)|019[23]))',
     '954' => '(?:(?:86(?:19|86)|019[25]))',
